==> org.opennms.features.api-layer-24.0.0-20190122.225206-63-sources.jar: org/opennms/features/apilayer/pollers/ServicePollerManager.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2018 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2018 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.apilayer.pollers;

import java.util.Hashtable;
import java.util.Map;

import org.opennms.features.apilayer.utils.InterfaceMapper;
import org.opennms.integration.api.v1.pollers.ServicePollerFactory;
import org.opennms.netmgt.poller.ServiceMonitor;
import org.osgi.framework.BundleContext;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Manager to plug the service pollers that implement integration-api to the default service poller registry.
 */
public class ServicePollerManager extends InterfaceMapper<ServicePollerFactory, ServiceMonitor> {

    private static final Logger LOG = LoggerFactory.getLogger(InterfaceMapper.class);

    public ServicePollerManager(BundleContext bundleContext) {
        super(ServiceMonitor.class, bundleContext);
    }

    @Override
    public ServiceMonitor map(ServicePollerFactory ext) {
        return new ServicePollerImpl(ext);
    }

    // Had to override as registry needs poller class name in properties.
    @Override
    public synchronized void onBind(ServicePollerFactory extension, Map properties) {
        LOG.debug("bind called with {}: {}", extension, properties);
        if (extension != null) {
            extServiceRegistrationMap.computeIfAbsent(extension, (ext) -> {
                final ServiceMonitor mappedExt = map(ext);
                final Hashtable<String, Object> props = new Hashtable<>();
                // Make the service available to any Spring-based listeners
                props.put("registration.export", Boolean.TRUE.toString());
                // Registry needs type of poller class.
                props.put("type", ext.getPollerClassName());
                return bundleContext.registerService(clazz, mappedExt, props);
            });
        }
    }
}

==> org.opennms.features.api-layer-27.0.0-20200502.023126-20-sources.jar: org/opennms/features/apilayer/pollers/ServicePollerManager.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2018 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2018 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.apilayer.pollers;

import java.util.HashMap;
import java.util.Map;

import org.opennms.features.apilayer.utils.InterfaceMapper;
import org.opennms.integration.api.v1.pollers.ServicePollerFactory;
import org.opennms.netmgt.poller.ServiceMonitor;
import org.osgi.framework.BundleContext;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Manager to plug the service pollers that implement integration-api to the default service poller registry.
 */
public class ServicePollerManager extends InterfaceMapper<ServicePollerFactory, ServiceMonitor> {

    private static final Logger LOG = LoggerFactory.getLogger(ServicePollerManager.class);

    public ServicePollerManager(BundleContext bundleContext) {
        super(ServiceMonitor.class, bundleContext);
    }

    @Override
    public ServiceMonitor map(ServicePollerFactory ext) {
        return new ServicePollerImpl(ext);
    }

    // override as registry needs poller class name in properties.
    @Override
    public Map<String, Object> getServiceProperties(ServicePollerFactory extension) {
        Map<String, Object> properties = new HashMap<>();
        properties.put("type", extension.getPollerClassName());
        return properties;
    }

}
